@@ -20,7 +20,7 @@ class Field(FrozenPydanticBase):
     field_type: FieldType
     validators: List[Validator] = []
     description: Optional[str] = None
-    schema_name: Optional[str] = None
+    json_schema: Optional[Schema] = None
 
     def is_nullable(self) -> bool:
         for v in self.validators:
@@ -262,6 +262,8 @@ def create_quick_schema(name: str, fields: List[Tuple[str, str]], **kwargs):
     return schema
 
 
+Field.update_forward_refs()
+
 AnySchema = Schema(
     name="Any",
     description="The Any root/super schema is compatible with all other Schemas",
